@@ -6,7 +6,7 @@ use Compiler::Lexer;
 use CPAN::Meta::Requirements;
 use Perl::PrereqScanner::Lite::Constants;
 
-our $VERSION = "0.14";
+our $VERSION = "0.15";
 
 sub new {
     my ($class, $opt) = @_;
@@ -80,6 +80,7 @@ sub _scan {
     my $is_inherited    = 0;
     my $is_in_list      = 0;
     my $is_version_decl = 0;
+    my $is_aliased      = 0;
     my $is_prev_module_name = 0;
 
     my $does_garbage_exist = 0;
@@ -143,10 +144,13 @@ sub _scan {
                     $latest_prereq = $self->_add_minimum($module_name, 0);
                     $does_use_lib_or_constant = 1;
                 }
-
-                if ($module_name =~ /(?:base|parent)/) {
+                elsif ($module_name =~ /(?:base|parent)/) {
                     $is_inherited = 1;
                 }
+                elsif ($module_name =~ 'aliased') {
+                    $is_aliased = 1;
+                }
+
                 $is_prev_module_name = 1;
                 next;
             }
@@ -165,6 +169,7 @@ sub _scan {
                 $is_inherited   = 0;
                 $is_in_list     = 0;
                 $is_in_usedecl  = 0;
+                $is_aliased     = 0;
                 $does_garbage_exist  = 0;
                 $is_prev_module_name = 0;
                 $does_use_lib_or_constant = 0;
@@ -247,6 +252,14 @@ sub _scan {
                 next;
             }
 
+            if ($is_aliased) {
+                if ($token_type == STRING || $token_type == RAW_STRING) {
+                    $latest_prereq = $self->_add_minimum($token->{data} => 0);
+                    $is_aliased = 0;
+                }
+                next;
+            }
+
             if ($token_type != WHITESPACE) {
                 $does_garbage_exist  = 1;
                 $is_prev_module_name = 0;
