@@ -7,25 +7,27 @@ use Perl::PrereqScanner::Lite::Constants;
 sub scan {
     my ($class, $c, $token, $token_type) = @_;
 
-    if ($token_type == KEY && $token->data eq 'extends') {
-        $c->{is_in_extends} = 1;
+    my $token_data = $token->data;
+    if ($token_type == KEY && $token_data eq 'extends' || $token_data eq 'with') {
+        $c->{is_in_moose_inherited} = 1;
         return 1;
     }
 
-    if ($c->{is_in_extends}) {
+    if ($c->{is_in_moose_inherited}) {
         # For qw() notation
         # e.g.
         #   extends qw/Foo Bar/;
+        #   with qw/Foo Bar/;
         if ($token_type == REG_LIST) {
-            $c->{is_in_extends_reglist} = 1;
+            $c->{is_in_moose_inherited_reglist} = 1;
             return 1;
         }
-        if ($c->{is_in_extends_reglist}) {
+        if ($c->{is_in_moose_inherited_reglist}) {
             if ($token_type == REG_EXP) {
-                for my $_module_name (split /\s+/, $token->data) {
+                for my $_module_name (split /\s+/, $token_data) {
                     $c->{module_reqs}->add_minimum($_module_name => 0);
                 }
-                $c->{is_in_extends_reglist} = 0;
+                $c->{is_in_moose_inherited_reglist} = 0;
             }
             return 1;
         }
@@ -33,17 +35,18 @@ sub scan {
         # For simply list
         # e.g.
         #   extends ('Foo' 'Bar');
+        #   with ('Foo' 'Bar');
         if ($token_type == LEFT_PAREN) {
-            $c->{is_in_extends_list} = 1;
+            $c->{is_in_moose_inherited_list} = 1;
             return 1;
         }
         if ($token_type == RIGHT_PAREN) {
-            $c->{is_in_extends_list} = 0;
+            $c->{is_in_moose_inherited_list} = 0;
             return 1;
         }
-        if ($c->{is_in_extends_list}) {
+        if ($c->{is_in_moose_inherited_list}) {
             if ($token_type == STRING || $token_type == RAW_STRING) {
-                $c->{module_reqs}->add_minimum($token->data => 0);
+                $c->{module_reqs}->add_minimum($token_data => 0);
             }
             return 1;
         }
@@ -51,16 +54,17 @@ sub scan {
         # For string
         # e.g.
         #   extends "Foo"
+        #   with "Foo"
         if ($token_type == STRING || $token_type == RAW_STRING) {
-            $c->{module_reqs}->add_minimum($token->data => 0);
+            $c->{module_reqs}->add_minimum($token_data => 0);
             return 1;
         }
 
-        # End of extends
+        # End of extends or with
         if ($token_type == SEMI_COLON) {
-            $c->{is_in_extends}         = 0;
-            $c->{is_in_extends_reglist} = 0;
-            $c->{is_in_extends_list}    = 0;
+            $c->{is_in_moose_inherited}         = 0;
+            $c->{is_in_moose_inherited_reglist} = 0;
+            $c->{is_in_moose_inherited_list}    = 0;
             return 1;
         }
 
@@ -87,7 +91,7 @@ Perl::PrereqScanner::Lite::Scanner::Moose - Extra Perl::PrereqScanner::Lite Scan
 
 =head1 DESCRIPTION
 
-Perl::PrereqScanner::Lite::Scanner::Moose is the extra scanner for Perl::PrereqScanner::Lite. This scanner supports C<extends> notation for Moose family.
+Perl::PrereqScanner::Lite::Scanner::Moose is the extra scanner for Perl::PrereqScanner::Lite. This scanner supports C<extends> and C<with> notation for Moose family.
 
 =head1 LICENSE
 
